@@ -74,6 +74,7 @@ if __name__ == "__main__":
         vecs2 = [code2vec.get_vector(w) for w in words2]
         vec1 = sum(vecs1) / len(vecs1)
         vec2 = sum(vecs2) / len(vecs2)
+        print(sum(vec1), sum(vec2))
         cos = np.dot(vec1, vec2) / np.linalg.norm(vec1) / np.linalg.norm(vec2)
         return cos / 2 + 0.5
 
@@ -102,6 +103,8 @@ if __name__ == "__main__":
     print(cos(code2vec, "clear", "seset"))
     print(cos(code2vec, "substr", "substring"))
     print(cos(code2vec, "rows", "columns"))
+    print(cos(code2vec, "db", "database"))
+    print(cos(code2vec, "md5", "file"))
     
     # print(cos(code2vec, "rr", "repfdsafsda"))
     # print(cos(code2vec, "x", "y"))
